# namecheck

<p align="left" width="250">
    <a href="https://github.com/pixelprotest/namecheck/actions">
        <img src="https://github.com/pixelprotest/namecheck/actions/workflows/tests.yml/badge.svg" alt="Tests Status">
    </a>
    <a href="">
        <img src="https://img.shields.io/github/v/release/pixelprotest/namecheck">
    </a>
    <a href="">
        <img src="https://img.shields.io/badge/python-3.10%20%7C%203.11%20%7C%203.12-blue">
    </a>
    <a href="">
        <img src="https://img.shields.io/github/license/pixelprotest/namecheck?label=license&style=flat">
    </a>
</p>

CLI utility to check the availability of project names on PyPi and TestPyPi

<img alt="Demo" width="100%" src="https://raw.githubusercontent.com/pixelprotest/namecheck/main/.github/demo.gif">


## 📦 Installation
Simple pip installation
```
pip install namecheck
```

## 🚀 Usage
Then to launch just run

```bash
namecheck
```

## License

MIT License. This project is for personal use.